pub struct EventDescription {
pub name: String,
pub description: I18nString,
pub color: String,
pub icon_url: String,
pub bg_url: String,
pub bg_path: String,
pub text_url: String,
pub effect_url: String,
pub ttl_milliseconds: u64,
}Fields
name: Stringdescription: I18nStringcolor: Stringicon_url: Stringbg_url: Stringbg_path: Stringtext_url: Stringeffect_url: Stringttl_milliseconds: u64Trait Implementations
Sourceimpl Clone for EventDescription
impl Clone for EventDescription
Sourcefn clone(&self) -> EventDescription
fn clone(&self) -> EventDescription
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventDescription
impl Debug for EventDescription
Sourceimpl<'de> Deserialize<'de> for EventDescription
impl<'de> Deserialize<'de> for EventDescription
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EventDescription
impl JsonSchema for EventDescription
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EventDescription
impl PartialEq for EventDescription
Sourceimpl Serialize for EventDescription
impl Serialize for EventDescription
Sourceimpl Tsify for EventDescription
impl Tsify for EventDescription
const DECL: &'static str = "export interface EventDescription {\n name: string;\n description: I18nString;\n color: string;\n icon_url: string;\n bg_url: string;\n bg_path: string;\n text_url: string;\n effect_url: string;\n ttl_milliseconds: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for EventDescription
impl StructuralPartialEq for EventDescription